@@ -1,6 +1,6 @@
 package Ion;
 # ABSTRACT: A clear and concise API for writing TCP servers and clients
-$Ion::VERSION = '0.02';
+$Ion::VERSION = '0.03';
 use common::sense;
 
 use Carp;
@@ -15,15 +15,20 @@ our @EXPORT = qw(
   Listen
 );
 
-sub Connect ($$) {
+sub Connect (;$$) {
   my ($host, $port) = @_;
   Ion::Conn->new(host => $host, port => $port);
 }
 
 sub Listen {
   my $service = pop;
-  my $server  = Ion::Server->new(port => shift, host => shift);
-  $server->start;
+
+  if (!ref $service || ref $service ne 'CODE') {
+    push @_, $service;
+  }
+
+  my $server = Ion::Server->new;
+  $server->start(shift, shift);
 
   if ($service) {
     async_pool {
@@ -62,7 +67,7 @@ Ion - A clear and concise API for writing TCP servers and clients
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
